@@ -1,4 +1,4 @@
-//$Id: button-canvas.h,v 1.7 2002/01/01 21:23:40 cactus Exp $ -*- c++ -*-
+//$Id: button-canvas.h,v 1.8 2002/01/28 18:21:58 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -21,6 +21,7 @@
 
 #include "button.h"
 #include "widget-canvas.h"
+#include "resizeable-canvas.h"
 
 namespace Guikachu
 {
@@ -28,7 +29,8 @@ namespace Guikachu
     {
 	namespace FormEditor
 	{
-	    class ButtonCanvasItem: public WidgetCanvasItem
+	    class ButtonCanvasItem: public WidgetCanvasItem,
+				    public ResizeableCanvasItem
 	    {
 		Widgets::Button    *widget;
 		Gnome::CanvasGroup *group;
@@ -38,8 +40,10 @@ namespace Guikachu
 				  Gnome::CanvasGroup *parent_group);
 
 	    protected:
-		virtual void update ();
-
+		void update ();
+		void get_bounds (int &x1, int &y1,
+				 int &x2, int &y2);
+		
 	    private:
 		void create_simple_border ();
 		void create_bold_border ();
