@@ -1,4 +1,4 @@
-//$Id: checkbox-prop.cc,v 1.11 2002/01/01 21:23:40 cactus Exp $ -*- c++ -*-
+//$Id: checkbox-prop.cc,v 1.12 2002/01/26 00:19:16 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -22,7 +22,7 @@
 #include <libgnome/libgnome.h>
 
 #include "widget-prop.h"
-#include "resizeable-prop.h"
+#include "auto-resizeable-prop.h"
 #include "textual-prop.h"
 
 
@@ -77,7 +77,8 @@ CheckboxProperties::CheckboxProperties (Checkbox *res)
     WidgetProperties::add_position_controls (res, *proptable);
 
     /* Size */
-    ResizeableProperties::add_controls (res, *proptable);
+    AutoWidthProperties::add_controls  (res, *proptable);
+    AutoHeightProperties::add_controls (res, *proptable);
     
     proptable->show ();
     property_editor = proptable;
