@@ -1,4 +1,4 @@
-//$Id: form-element.h,v 1.2 2002/01/01 21:23:40 cactus Exp $ -*- c++ -*-
+//$Id: form-element.h,v 1.4 2002/02/05 15:08:56 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -31,8 +31,14 @@ namespace Guikachu
 	virtual ~FormElement () {};
 
     public:
+	// Position
 	virtual int get_x () const = 0;
 	virtual int get_y () const = 0;
+	virtual void set_x (int x) = 0;
+	virtual void set_y (int y) = 0;
+	
+	SigC::Signal1<void, bool> selected;
+	SigC::Signal0<void>       request_edit;
     };
 }
 
