@@ -1,4 +1,4 @@
-//$Id: gadget-canvas.h,v 1.3 2002/01/01 21:23:40 cactus Exp $ -*- c++ -*-
+//$Id: gadget-canvas.h,v 1.4 2002/02/10 00:01:19 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -21,6 +21,7 @@
 
 #include "gadget.h"
 #include "widget-canvas.h"
+#include "resizeable-canvas.h"
 
 namespace Guikachu
 {
@@ -28,7 +29,8 @@ namespace Guikachu
     {
 	namespace FormEditor
 	{
-	    class GadgetCanvasItem: public WidgetCanvasItem
+	    class GadgetCanvasItem: public WidgetCanvasItem,
+				    public ResizeableCanvasItem
 	    {
 		Widgets::Gadget    *widget;
 		Gnome::CanvasGroup *group;
