@@ -1,4 +1,4 @@
-//$Id: label-canvas.cc,v 1.9 2002/01/01 21:23:40 cactus Exp $ -*- c++ -*-
+//$Id: label-canvas.cc,v 1.11 2002/01/29 22:55:05 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -26,6 +26,7 @@ using namespace Guikachu::GUI::FormEditor;
 
 LabelCanvasItem::LabelCanvasItem (Widgets::Label     *widget_,
 				  Gnome::CanvasGroup *parent_group):
+    CanvasItem (widget_, parent_group),
     WidgetCanvasItem (widget_, parent_group),
     widget (widget_),
     group (0)
@@ -38,7 +39,7 @@ void LabelCanvasItem::update ()
     if (group)
 	delete group;
     
-    group = new Gnome::CanvasGroup (*parent_group, 0, 0);
+    group = new Gnome::CanvasGroup (*draw_group, 0, 0);
 
     draw_text (*group,
 	       widget->text, widget->font,
