@@ -1,4 +1,4 @@
-//$Id: list-canvas.cc,v 1.18 2002/01/01 21:23:40 cactus Exp $ -*- c++ -*-
+//$Id: list-canvas.cc,v 1.20 2002/01/29 22:55:05 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -27,6 +27,7 @@ using namespace Guikachu::GUI::FormEditor;
 
 ListCanvasItem::ListCanvasItem (Widgets::List      *widget_,
 				Gnome::CanvasGroup *parent_group):
+    CanvasItem (widget_, parent_group),
     WidgetCanvasItem (widget_, parent_group),
     widget (widget_),
     group (0)
@@ -39,7 +40,7 @@ void ListCanvasItem::update ()
     if (group)
 	delete group;
     
-    group = new Gnome::CanvasGroup (*parent_group, 0, 0);
+    group = new Gnome::CanvasGroup (*draw_group, 0, 0);
 
     int font_num = widget->font;    
     int height = get_font_height (font_num) * widget->visible_items;
