@@ -1,4 +1,4 @@
-//$Id: list-prop.cc,v 1.12 2002/01/01 21:23:40 cactus Exp $ -*- c++ -*-
+//$Id: list-prop.cc,v 1.13 2002/01/05 23:35:20 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -29,6 +29,7 @@
 #include "widgets/auto-toggle.h"
 #include "widgets/propertytable.h"
 #include "widgets/string-list.h"
+#include "widgets/font-combo.h"
 
 #include <gtk--/notebook.h>
 
@@ -52,7 +53,7 @@ ListProperties::ListProperties (List *res)
     WidgetProperties::add_general_controls (res, *proptable);
 
     /* Font */
-    control = new GUI::PropertyEditors::NumEntry (0, 2, res->font);
+    control = new GUI::PropertyEditors::FontCombo (res->font);
     proptable->add (_("_Font:"), *manage (control));
 
     /* Number of visible items */
