@@ -1,6 +1,6 @@
-//$Id: list.cc,v 1.15 2001/11/15 20:22:00 cactus Exp $ -*- c++ -*-
+//$Id: list.cc,v 1.17 2002/01/01 21:23:40 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -52,9 +52,9 @@ Gtk::Widget *List::create_editor ()
     return editor->get_editor ();
 }
 
-CanvasItem* List::create_canvas_item (GUI::FormEditor::Form *form)
+WidgetCanvasItem* List::create_canvas_item (Gnome::CanvasGroup *parent_group)
 {
-    return new ListCanvasItem (this, form);
+    return new ListCanvasItem (this, parent_group);
 }
 
 bool List::load (StorageNode &node)
