@@ -1,4 +1,4 @@
-//$Id: resizeable-prop.cc,v 1.6 2002/01/01 21:23:40 cactus Exp $ -*- c++ -*-
+//$Id: resizeable-prop.cc,v 1.8 2002/02/10 00:01:19 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -22,26 +22,35 @@
 #include <libgnome/libgnome.h>
 
 #include "widgets/size-entry.h"
-#include "widgets/auto-toggle.h"
 
 using namespace Guikachu::GUI::FormEditor;
 
-void ResizeableProperties::add_controls (Widgets::Resizeable *res,
-					 GUI::PropertyTable  &proptable)
+void ResizeableProperties::add_width_controls (Widgets::Resizeable *res,
+					       GUI::PropertyTable  &proptable)
 {
     Gtk::Widget *control;
     
     /* Width */
     control = new GUI::PropertyEditors::WidthEntry (res->width);
-    control = new GUI::PropertyEditors::AutoToggle (*manage (control), res->manual_width);
     proptable.add (_("_Width:"), *manage (control),
-		   _("Horizontal size of the widget "
-		     "(check to set manually)"));
+		   _("Horizontal size of the widget"));    
+}
 
+void ResizeableProperties::add_height_controls (Widgets::Resizeable *res,
+					       GUI::PropertyTable  &proptable)
+{
+    Gtk::Widget *control;
+    
     /* Height */
     control = new GUI::PropertyEditors::HeightEntry (res->height);
-    control = new GUI::PropertyEditors::AutoToggle (*manage (control), res->manual_height);
     proptable.add (_("_Height:"), *manage (control),
-		   _("Vertical size of the widget "
-		     "(check to set manually)"));
+		   _("Vertical size of the widget"));
+    
+}
+
+void ResizeableProperties::add_controls (Widgets::Resizeable *res,
+					 GUI::PropertyTable  &proptable)
+{
+    add_width_controls  (res, proptable);
+    add_height_controls (res, proptable);
 }
