@@ -1,4 +1,4 @@
-//$Id: resizeable.cc,v 1.4 2002/01/01 21:23:40 cactus Exp $ -*- c++ -*-
+//$Id: resizeable.cc,v 1.6 2002/01/30 17:33:10 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -23,44 +23,25 @@
 using namespace Guikachu::Widgets;
 
 Resizeable::Resizeable (SigC::Signal0<void> &changed):
-    changed_propagate (changed),
-    width (changed, 0),
-    manual_width (manual_width_changed, false),
-    height (changed, 0),
-    manual_height (manual_height_changed, false)
+    real_changed (changed),
+    width (width_changed, 0),
+    height (height_changed, 0)
 {
-    manual_width_changed.connect (SigC::slot (this, &Resizeable::manual_width_cb));
-    manual_height_changed.connect (SigC::slot (this, &Resizeable::manual_height_cb));
+    width_changed.connect (SigC::slot (this, &Resizeable::emit_changed));
+    height_changed.connect (SigC::slot (this, &Resizeable::emit_changed));
 }
 
-int Resizeable::get_display_width () const
+void Resizeable::emit_changed ()
 {
-    if (manual_width && width != 0)
-	return width;
-    else
-	return get_auto_width ();
+    real_changed.emit ();
+}
+
+int Resizeable::get_display_width  () const
+{
+    return width;
 }
 
 int Resizeable::get_display_height () const
 {
-    if (manual_height && height != 0)
-	return height;
-    else
-	return get_auto_height ();
-}
-
-void Resizeable::manual_width_cb ()
-{
-    if (width == 0)
-	width = get_auto_width ();
-    else
-	changed_propagate.emit ();
-}
-
-void Resizeable::manual_height_cb ()
-{
-    if (height == 0)
-	height = get_auto_height ();
-    else
-	changed_propagate.emit ();
+    return height;
 }
