@@ -1,4 +1,4 @@
-//$Id: scrollbar.cc,v 1.15 2002/01/01 21:23:40 cactus Exp $ -*- c++ -*-
+//$Id: scrollbar.cc,v 1.16 2002/01/30 17:33:10 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -29,18 +29,19 @@ using namespace Guikachu::GUI::FormEditor;
 ScrollBar::ScrollBar (Resources::Form   *owner,
 		      const std::string &id):
     Widget (owner, id),
+    Resizeable (changed),
+    AutoWidth (changed),
+    
     editor (0),
     usable (changed, true),
     min_value (changed, 0),
     max_value (changed, 0),
     value (changed, 0),
-    page_size (changed, 0),
-    width (changed, 0),
-    manual_width (manual_width_changed, false),
-    height (changed, 40)
+    page_size (changed, 0)
 {
+    height = 40;
+    
     changed.connect (SigC::slot (this, &ScrollBar::update));
-    manual_width_changed.connect (SigC::slot (this, &ScrollBar::manual_width_cb));
 }
 
 ScrollBar::~ScrollBar ()
@@ -182,23 +183,7 @@ void ScrollBar::save_rcp (std::ostream &ostr) const
     g_free (width_str);
 }
 
-int ScrollBar::get_display_width () const
-{
-    if (manual_width && width != 0)
-	return width;
-    else
-	return get_auto_width ();
-}
-
 int ScrollBar::get_auto_width () const
 {
     return 7; /* recommended width for scroll bars */
 }
-
-void ScrollBar::manual_width_cb ()
-{
-    if (width == 0)
-	width = get_auto_width ();
-    else
-	changed.emit ();
-}
