@@ -1,4 +1,4 @@
-//$Id: selector-trigger.cc,v 1.16 2002/01/01 21:23:40 cactus Exp $ -*- c++ -*-
+//$Id: selector-trigger.cc,v 1.17 2002/01/26 00:19:17 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -28,6 +28,8 @@ SelectorTrigger::SelectorTrigger (Resources::Form   *owner,
 				  const std::string &id):
     Widget (owner, id),
     Resizeable (changed),
+    AutoWidth (changed),
+    AutoHeight (changed),
     Textual (changed, id),
     editor (0),
     usable (changed, true),
