@@ -1,4 +1,4 @@
-//$Id: text-field-canvas.cc,v 1.7 2002/01/01 21:23:41 cactus Exp $ -*- c++ -*-
+//$Id: text-field-canvas.cc,v 1.10 2002/02/10 00:01:19 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -25,7 +25,9 @@ using namespace Guikachu::GUI::FormEditor;
 
 TextFieldCanvasItem::TextFieldCanvasItem (Widgets::TextField *widget_,
 					  Gnome::CanvasGroup *parent_group):
+    CanvasItem (widget_, parent_group),
     WidgetCanvasItem (widget_, parent_group),
+    ResizeableCanvasItem (widget_, parent_group),
     widget (widget_),
     group (0)
 {
@@ -37,7 +39,7 @@ void TextFieldCanvasItem::update ()
     if (group)
 	delete group;
     
-    group = new Gnome::CanvasGroup (*parent_group, 0, 0);
+    group = new Gnome::CanvasGroup (*draw_group, 0, 0);
 
     const Font &font = get_font (widget->font);
     int height = widget->get_display_height ();
