@@ -1,4 +1,4 @@
-//$Id: text-field-prop.cc,v 1.7 2002/01/05 23:35:20 cactus Exp $ -*- c++ -*-
+//$Id: text-field-prop.cc,v 1.8 2002/02/10 00:01:19 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -23,6 +23,7 @@
 
 #include "widget-prop.h"
 #include "resizeable-prop.h"
+#include "auto-resizeable-prop.h"
 #include "textual-prop.h"
 
 
@@ -111,7 +112,8 @@ TextFieldProperties::TextFieldProperties (TextField *res)
     WidgetProperties::add_position_controls (res, *proptable);
 
     /* Size */
-    ResizeableProperties::add_controls (res, *proptable);
+    ResizeableProperties::add_width_controls (res, *proptable);
+    AutoHeightProperties::add_controls (res, *proptable);
     
     proptable->show ();
     property_editor = proptable;
