@@ -1,4 +1,4 @@
-//$Id: form-win.cc,v 1.46 2002/01/01 21:23:39 cactus Exp $ -*- c++ -*-
+//$Id: form-win.cc,v 1.48 2002/02/08 23:29:42 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -280,7 +280,7 @@ void FormWindow::widget_created_cb (Widget *widget)
 void FormWindow::widget_removed_cb (Widget *widget)
 {
     // Remove from selection
-    selected_widgets.erase (widget);
+    selection_remove (widget);
 
     // Remove property editor
     if (widget == edited_widget)
@@ -410,6 +410,40 @@ void FormWindow::show_form_property_editor ()
     property_window->get_window ().raise ();
 }
 
+void FormWindow::selection_add (Widget *widget)
+{
+    selected_widgets.insert (widget);
+    widget->selected (true);
+}
+
+void FormWindow::selection_remove (Widget *widget)
+{
+#if 0
+    if (selected_widgets.find (widget) == selected_widgets.end ())
+	return;
+#endif
+    
+    selected_widgets.erase (widget);
+    widget->selected (false);
+}
+
+void FormWindow::selection_toggle (Widget *widget)
+{
+    if (selected_widgets.find (widget) == selected_widgets.end ())
+	selection_add (widget);
+    else
+	selection_remove (widget);
+}
+
+void FormWindow::selection_clear ()
+{
+    for (std::set<Widget*>::iterator i = selected_widgets.begin ();
+	 i != selected_widgets.end (); i++)
+	(*i)->selected (false);
+    
+    selected_widgets.clear ();
+}
+
 void FormWindow::form_select_cb ()
 {
     bool add_to_selection;
@@ -424,13 +458,8 @@ void FormWindow::form_select_cb ()
 
     if (add_to_selection)
 	return;
-    
-    for (std::set<Widget*>::iterator i = selected_widgets.begin ();
-	 i != selected_widgets.end (); i++)
-    {
-	(*i)->selected (false);
-	selected_widgets.erase (i);
-    }
+
+    selection_clear ();
     
     form_widget->selected (true);
     top_treeitem->select ();
@@ -456,28 +485,14 @@ void FormWindow::widget_select_cb (Widget *widget)
     
     if (!add_to_selection)
     {
-	if (selected_widgets.find (widget) != selected_widgets.end ())
-	    return;
-    
-	for (std::set<Widget*>::iterator i = selected_widgets.begin ();
-	     i != selected_widgets.end (); i++)
+	if (selected_widgets.find (widget) == selected_widgets.end ())
 	{
-	    (*i)->selected (false);
-	    selected_widgets.erase (i);
+	    selection_clear ();
+	    selection_add (widget);
 	}
-	
     } else {
-
-	if (selected_widgets.find (widget) != selected_widgets.end ())
-	{
-	    selected_widgets.erase (widget);
-	    widget->selected (false);
-	    return;
-	}
+	selection_toggle (widget);
     }
-
-    widget->selected (true);
-    selected_widgets.insert (widget);
 }
 
 void FormWindow::form_clicked_cb ()
@@ -511,6 +526,12 @@ void FormWindow::widget_released_cb (Widget *widget)
 void FormWindow::selection_box_cb (int x1, int y1,
 				   int x2, int y2)
 {
+    x1 -= res->x;
+    x2 -= res->x;
+
+    y1 -= res->y;
+    y2 -= res->y;
+    
     bool add_to_selection;
     
     {
@@ -522,15 +543,7 @@ void FormWindow::selection_box_cb (int x1, int y1,
     }
 
     if (!add_to_selection)
-    {
-	for (std::set<Widget*>::const_iterator i = selected_widgets.begin ();
-	     i != selected_widgets.end (); i++)
-	{
-	    (*i)->selected (false);
-	}
-	
-	selected_widgets.clear ();
-    }
+	selection_clear ();
 
     const std::set<Widget*>& widgets = res->get_widgets ();
     for (std::set<Widget*>::const_iterator i = widgets.begin ();
@@ -538,12 +551,9 @@ void FormWindow::selection_box_cb (int x1, int y1,
     {
 	FormEditor::WidgetCanvasItem *canvas_item =
 	    (*i)->get_canvas_item (form_canvas_item->get_widget_group ());
-
+	
 	if (canvas_item->is_within (x1, y1, x2, y2))
-	{
-	    (*i)->selected (true);
-	    selected_widgets.insert (*i);
-	}
+	    selection_add (*i);
     }
 }
 
