@@ -1,4 +1,4 @@
-//$Id: form-win.h,v 1.29 2002/01/01 21:23:39 cactus Exp $ -*- c++ -*-
+//$Id: form-win.h,v 1.30 2002/02/08 23:29:42 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -106,6 +106,11 @@ namespace Guikachu
 
 	    void widget_menu_remove_cb (Widget *widget);
 
+	    void selection_add    (Widget *widget);
+	    void selection_remove (Widget *widget);
+	    void selection_toggle (Widget *widget);
+	    void selection_clear  ();
+	    
 	    void form_select_cb   ();
 	    void form_clicked_cb  ();
 	    void form_released_cb ();
