@@ -1,4 +1,4 @@
-//$Id: storage-node.h,v 1.8 2002/01/01 21:23:39 cactus Exp $ -*- c++ -*-
+//$Id: storage-node.h,v 1.9 2002/01/08 23:27:07 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -32,8 +32,8 @@ namespace Guikachu
 	StorageNode ();
 	StorageNode (xmlNodePtr root);
 
-	inline std::string name   () const { return (char*)(node_ptr->name); };
-	inline xmlNodePtr  c_node () const { return node_ptr; };
+	std::string name () const;
+	inline xmlNodePtr c_node () const { return node_ptr; };
 	
 	/* Tree management */
 	StorageNode add_node (const std::string &name,
@@ -42,6 +42,8 @@ namespace Guikachu
 	StorageNode children () const { return node_ptr->xmlChildrenNode; };
 	StorageNode next ()     const;
 	StorageNode &operator++ (int) { node_ptr = next ().c_node (); return *this; };
+
+	StorageNode get_translated_child (const std::string &name) const;
 	
 	inline operator bool () { return node_ptr != 0; }
 	
