@@ -1,6 +1,6 @@
-//$Id: pos-entry.h,v 1.4 2001/12/19 17:56:53 cactus Exp $ -*- c++ -*-
+//$Id: pos-entry.h,v 1.6 2002/01/01 21:23:42 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -31,12 +31,16 @@ namespace Guikachu
 	    {
 	    public:
 		XPosEntry (Property<int> &property);
+	    private:
+		void target_changed_cb ();
 	    };
 
 	    class YPosEntry: public NumEntry
 	    {
 	    public:
 		YPosEntry (Property<int> &property);
+	    private:
+		void target_changed_cb ();
 	    };
 	}
     }
